/*
 *
 * MassChroQ: Mass Chromatogram Quantification software.
 * Copyright (C) 2010 Olivier Langella, Edlira Nano, Benoit Valot, Michel Zivy.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
/**
 * \file quantificationMethod.h
 * \date October 26, 2010
 * \author Edlira Nano
 */

#ifndef QUANTIFICATION_METHOD_H_
#define QUANTIFICATION_METHOD_H_ 1

#include <QTextStream>
#include <pappsomspp/types.h>
#include <pappsomspp/xic/detection/xicdetectioninterface.h>
#include <pappsomspp/xic/filters/xicfilterinterface.h>

/**
   \class QuantificationMethod
   \brief Represents a method of quantification
*/
class QuantificationMethod {

public:
  QuantificationMethod(const QString &xml_id);
  QuantificationMethod(const QuantificationMethod &other);
  virtual ~QuantificationMethod();

  const QString &getXmlId() const;

  virtual void printInfos(QTextStream &out) const;

  void setDetectionMethod(pappso::XicDetectionInterface *detection_method);

  const pappso::XicDetectionInterface *getDetectionMethod() const;

  void setXicExtractMethod(pappso::XicExtractMethod xic_type);

  pappso::XicExtractMethod getXicExtractMethod() const;

  void addFilter(pappso::XicFilterInterface *filter);

  const pappso::XicFilterInterface *getXicFilters() const;

  pappso::PrecisionP getLowerPrecision() const;
  pappso::PrecisionP getUpperPrecision() const;
  pappso::PrecisionP getMeanPrecision() const;

  const pappso::MassRange getMassRange(pappso::mz mz) const;

  void setXicExtractLowerPrecision(pappso::pappso_double min);
  void setXicExtractUpperPrecision(pappso::pappso_double max);

  void setXicExtractPrecision(pappso::PrecisionP precision);

private:
  /// unique xml id for this method
  const QString _xml_id;

  /// the xic filters
  pappso::XicFilterInterface *_p_xic_filter = nullptr;

  /// the peak detection method for this quantification
  pappso::XicDetectionInterface *_p_detection_method = nullptr;

  pappso::XicExtractMethod _m_xic_extract_method =
      pappso::XicExtractMethod::max;

  pappso::PrecisionUnit _precision_unit = pappso::PrecisionUnit::ppm;

  pappso::pappso_double _upper_precision = 10;
  pappso::pappso_double _lower_precision = 10;

  pappso::PrecisionP _lower_precision_p = nullptr;
  pappso::PrecisionP _upper_precision_p = nullptr;
};

#endif /* QUANTIFICATION_METHOD_H_ */
