
/*******************************************************************************
 * Copyright (c) 2016 Olivier Langella <Olivier.Langella@moulon.inra.fr>.
 *
 * This file is part of the MassChroQ software.
 *
 *     MassChroQ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     MassChroQ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contributors:
 *     Olivier Langella <Olivier.Langella@moulon.inra.fr> - initial API and
 *implementation
 ******************************************************************************/
#include "alignedxicpeak.h"
#include "../mcq_error.h"
#include <QDataStream>
#include <QDebug>

AlignedXicPeak::AlignedXicPeak(const pappso::XicPeak &peak,
                               const Msrun *p_msrun)
    : pappso::XicPeak(peak) {
  _left.rt = p_msrun->getAlignedRtByOriginalRt(_left.rt);
  _right.rt = p_msrun->getAlignedRtByOriginalRt(_right.rt);
  _max.rt = p_msrun->getAlignedRtByOriginalRt(_max.rt);
}

AlignedXicPeak::AlignedXicPeak(const AlignedXicPeak &other)
    : pappso::XicPeak(other) {}

AlignedXicPeak::~AlignedXicPeak() {}

void AlignedXicPeak::serialize(QDataStream *p_outputstream) const {
  qDebug() << "AlignedXicPeak::serialize begin";
  try {
    (*p_outputstream) << _area << _left.rt << _left.intensity << _max.rt
                      << _max.intensity << _right.rt << _right.intensity;
  } catch (exception ex) {
    qDebug() << QObject::tr("error in AlignedXicPeak::serialize :\n%1")
                    .arg(ex.what());
    throw mcqError(
        QObject::tr("error in AlignedXicPeak::serialize :\n%1").arg(ex.what()));
  }
  qDebug() << "AlignedXicPeak::serialize end";
}

bool AlignedXicPeak::unserialize(QDataStream *instream) {
  *instream >> _area;
  *instream >> _left.rt;
  *instream >> _left.intensity;
  *instream >> _max.rt;
  *instream >> _max.intensity;
  *instream >> _right.rt;
  *instream >> _right.intensity;

  if (instream->status() != QDataStream::Ok) {
    throw mcqError(
        QString("error in AlignedXicPeak::unserialize :\nread AlignedXicPeak "
                "from datastream failed. QDataStream status=%1")
            .arg(instream->status()));
  }
  return true;
}
